AccessModel class
Constructors
- AccessModel({String resource = '', String resourceType = '', String permission = ''})
-
AccessModel.fromJson(Map<
String, dynamic> json) -
factory
- AccessModel.fromRawJson(String str)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- permission ↔ String
-
getter/setter pair
- resource ↔ String
-
getter/setter pair
- resourceType ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toRawJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited