SsoAuthModel class

Constructors

SsoAuthModel({required String accessToken, required int expiresIn, required int refreshExpiresIn, required String refreshToken, required String tokenType, required int notBeforePolicy, required String sessionState, required String scope})
SsoAuthModel.fromJson(Map<String, dynamic> json)
factory
SsoAuthModel.fromRawJson(String str)
factory

Properties

accessToken String
getter/setter pair
expiresIn int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
notBeforePolicy int
getter/setter pair
refreshExpiresIn int
getter/setter pair
refreshToken String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope String
getter/setter pair
sessionState String
getter/setter pair
tokenType String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited